import java.awt.*;

public class PlanetCanvas 
	extends Canvas
	implements PlanetListener
{
	private Planet m_planet;
	
	public void paint(Graphics g)
	{
		g.setColor(m_planet.getColor());
		g.fillOval(0, 0, getWidth(), getHeight());
	}
	
	public PlanetCanvas(Planet p)
	{
		m_planet = p;		
		double maxR = 0;
		for (Planet q : Planet.values())
			maxR = Math.max(maxR, q.getRadius());
		int r = (int)(
				Math.log(p.getRadius() / maxR  * (Math.E - 1) + 1)* 10 + .5);
		r = Math.max(r, 1);
		setSize(2 * r, 2 * r);
		p.addListener(this);
	}
	
	public static int getPlanetX(Planet p, Container parent)
	{
		double maxDist = 0;
		for (Planet q : Planet.values())
			maxDist = Math.max(maxDist, q.getDistance());
		int width = parent.getWidth();
		int height = parent.getHeight();
		int dim = Math.min(width, height)-50;
		double scale = dim /maxDist / 2;
		int x = (int)(p.getX() * scale + width / 2);
		return x;		
	}

	public static int getPlanetY(Planet p, Container parent)
	{
		double maxDist = 0;
		for (Planet q : Planet.values())
			maxDist = Math.max(maxDist, q.getDistance());
		int width = parent.getWidth();
		int height = parent.getHeight();
		int dim = Math.min(width, height)-50;
		double scale = dim /maxDist / 2;
		int y = (int)(p.getY() * scale + height / 2);
		return y;		
	}
	
	public void planetMoved(Planet p)
	{
		int x = getPlanetX(p, getParent());
		int y = getPlanetY(p, getParent());
		x -= getWidth() / 2;
		y -= getHeight() / 2;
		setLocation(x, y);		
		getParent().repaint();
	}
}
